==> istio-model-v1beta1-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/IstioEgressListenerFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IstioEgressListenerFluentImpl<A extends IstioEgressListenerFluent<A>> extends BaseFluent<A> implements IstioEgressListenerFluent<A>{
  public IstioEgressListenerFluentImpl() {
  }
  public IstioEgressListenerFluentImpl(IstioEgressListener instance) {
    this.withBind(instance.getBind()); 
    this.withCaptureMode(instance.getCaptureMode()); 
    this.withHosts(instance.getHosts()); 
    this.withPort(instance.getPort()); 
  }
  private String bind;
  private CaptureMode captureMode;
  private List<String> hosts = new ArrayList<String>();
  private PortBuilder port;
  public String getBind() {
    return this.bind;
  }
  public A withBind(String bind) {
    this.bind=bind; return (A) this;
  }
  public Boolean hasBind() {
    return this.bind != null;
  }
  public CaptureMode getCaptureMode() {
    return this.captureMode;
  }
  public A withCaptureMode(CaptureMode captureMode) {
    this.captureMode=captureMode; return (A) this;
  }
  public Boolean hasCaptureMode() {
    return this.captureMode != null;
  }
  public A addToHosts(Integer index,String item) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    this.hosts.add(index, item);
    return (A)this;
  }
  public A setToHosts(Integer index,String item) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    this.hosts.set(index, item); return (A)this;
  }
  public A addToHosts(java.lang.String... items) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    for (String item : items) {this.hosts.add(item);} return (A)this;
  }
  public A addAllToHosts(Collection<String> items) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    for (String item : items) {this.hosts.add(item);} return (A)this;
  }
  public A removeFromHosts(java.lang.String... items) {
    for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
  }
  public A removeAllFromHosts(Collection<String> items) {
    for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
  }
  public List<String> getHosts() {
    return this.hosts;
  }
  public String getHost(Integer index) {
    return this.hosts.get(index);
  }
  public String getFirstHost() {
    return this.hosts.get(0);
  }
  public String getLastHost() {
    return this.hosts.get(hosts.size() - 1);
  }
  public String getMatchingHost(Predicate<String> predicate) {
    for (String item: hosts) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingHost(Predicate<String> predicate) {
    for (String item: hosts) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withHosts(List<String> hosts) {
    if (hosts != null) {this.hosts = new ArrayList(); for (String item : hosts){this.addToHosts(item);}} else { this.hosts = null;} return (A) this;
  }
  public A withHosts(java.lang.String... hosts) {
    if (this.hosts != null) {this.hosts.clear();}
    if (hosts != null) {for (String item :hosts){ this.addToHosts(item);}} return (A) this;
  }
  public Boolean hasHosts() {
    return hosts != null && !hosts.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public Port getPort() {
    return this.port!=null ?this.port.build():null;
  }
  public Port buildPort() {
    return this.port!=null ?this.port.build():null;
  }
  public A withPort(Port port) {
    _visitables.get("port").remove(this.port);
    if (port!=null){ this.port= new PortBuilder(port); _visitables.get("port").add(this.port);} else { this.port = null; _visitables.get("port").remove(this.port); } return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public A withNewPort(String name,Integer number,String protocol,Integer targetPort) {
    return (A)withPort(new Port(name, number, protocol, targetPort));
  }
  public IstioEgressListenerFluent.PortNested<A> withNewPort() {
    return new IstioEgressListenerFluentImpl.PortNestedImpl();
  }
  public IstioEgressListenerFluent.PortNested<A> withNewPortLike(Port item) {
    return new IstioEgressListenerFluentImpl.PortNestedImpl(item);
  }
  public IstioEgressListenerFluent.PortNested<A> editPort() {
    return withNewPortLike(getPort());
  }
  public IstioEgressListenerFluent.PortNested<A> editOrNewPort() {
    return withNewPortLike(getPort() != null ? getPort(): new PortBuilder().build());
  }
  public IstioEgressListenerFluent.PortNested<A> editOrNewPortLike(Port item) {
    return withNewPortLike(getPort() != null ? getPort(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IstioEgressListenerFluentImpl that = (IstioEgressListenerFluentImpl) o;
    if (bind != null ? !bind.equals(that.bind) :that.bind != null) return false;
    if (captureMode != null ? !captureMode.equals(that.captureMode) :that.captureMode != null) return false;
    if (hosts != null ? !hosts.equals(that.hosts) :that.hosts != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bind,  captureMode,  hosts,  port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bind != null) { sb.append("bind:"); sb.append(bind + ","); }
    if (captureMode != null) { sb.append("captureMode:"); sb.append(captureMode + ","); }
    if (hosts != null && !hosts.isEmpty()) { sb.append("hosts:"); sb.append(hosts + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  class PortNestedImpl<N> extends PortFluentImpl<IstioEgressListenerFluent.PortNested<N>> implements IstioEgressListenerFluent.PortNested<N>,Nested<N>{
    PortNestedImpl(Port item) {
      this.builder = new PortBuilder(this, item);
    }
    PortNestedImpl() {
      this.builder = new PortBuilder(this);
    }
    PortBuilder builder;
    public N and() {
      return (N) IstioEgressListenerFluentImpl.this.withPort(builder.build());
    }
    public N endPort() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/IstioEgressListenerFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IstioEgressListenerFluentImpl<A extends IstioEgressListenerFluent<A>> extends BaseFluent<A> implements IstioEgressListenerFluent<A>{
  public IstioEgressListenerFluentImpl() {
  }
  public IstioEgressListenerFluentImpl(IstioEgressListener instance) {
    if (instance != null) {
      this.withBind(instance.getBind());
      this.withCaptureMode(instance.getCaptureMode());
      this.withHosts(instance.getHosts());
      this.withPort(instance.getPort());
    }
  }
  private String bind;
  private CaptureMode captureMode;
  private List<String> hosts = new ArrayList<String>();
  private PortBuilder port;
  public String getBind() {
    return this.bind;
  }
  public A withBind(String bind) {
    this.bind=bind; return (A) this;
  }
  public Boolean hasBind() {
    return this.bind != null;
  }
  public CaptureMode getCaptureMode() {
    return this.captureMode;
  }
  public A withCaptureMode(CaptureMode captureMode) {
    this.captureMode=captureMode; return (A) this;
  }
  public Boolean hasCaptureMode() {
    return this.captureMode != null;
  }
  public A addToHosts(int index,String item) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    this.hosts.add(index, item);
    return (A)this;
  }
  public A setToHosts(int index,String item) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    this.hosts.set(index, item); return (A)this;
  }
  public A addToHosts(java.lang.String... items) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    for (String item : items) {this.hosts.add(item);} return (A)this;
  }
  public A addAllToHosts(Collection<String> items) {
    if (this.hosts == null) {this.hosts = new ArrayList<String>();}
    for (String item : items) {this.hosts.add(item);} return (A)this;
  }
  public A removeFromHosts(java.lang.String... items) {
    for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
  }
  public A removeAllFromHosts(Collection<String> items) {
    for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
  }
  public List<String> getHosts() {
    return this.hosts;
  }
  public String getHost(int index) {
    return this.hosts.get(index);
  }
  public String getFirstHost() {
    return this.hosts.get(0);
  }
  public String getLastHost() {
    return this.hosts.get(hosts.size() - 1);
  }
  public String getMatchingHost(Predicate<String> predicate) {
    for (String item: hosts) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingHost(Predicate<String> predicate) {
    for (String item: hosts) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withHosts(List<String> hosts) {
    if (hosts != null) {this.hosts = new ArrayList(); for (String item : hosts){this.addToHosts(item);}} else { this.hosts = null;} return (A) this;
  }
  public A withHosts(java.lang.String... hosts) {
    if (this.hosts != null) {this.hosts.clear(); _visitables.remove("hosts"); }
    if (hosts != null) {for (String item :hosts){ this.addToHosts(item);}} return (A) this;
  }
  public Boolean hasHosts() {
    return hosts != null && !hosts.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public Port getPort() {
    return this.port!=null ?this.port.build():null;
  }
  public Port buildPort() {
    return this.port!=null ?this.port.build():null;
  }
  public A withPort(Port port) {
    _visitables.get("port").remove(this.port);
    if (port!=null){ this.port= new PortBuilder(port); _visitables.get("port").add(this.port);} else { this.port = null; _visitables.get("port").remove(this.port); } return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public A withNewPort(String name,Integer number,String protocol,Integer targetPort) {
    return (A)withPort(new Port(name, number, protocol, targetPort));
  }
  public IstioEgressListenerFluentImpl.PortNested<A> withNewPort() {
    return new IstioEgressListenerFluentImpl.PortNestedImpl();
  }
  public IstioEgressListenerFluentImpl.PortNested<A> withNewPortLike(Port item) {
    return new IstioEgressListenerFluentImpl.PortNestedImpl(item);
  }
  public IstioEgressListenerFluentImpl.PortNested<A> editPort() {
    return withNewPortLike(getPort());
  }
  public IstioEgressListenerFluentImpl.PortNested<A> editOrNewPort() {
    return withNewPortLike(getPort() != null ? getPort(): new PortBuilder().build());
  }
  public IstioEgressListenerFluentImpl.PortNested<A> editOrNewPortLike(Port item) {
    return withNewPortLike(getPort() != null ? getPort(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IstioEgressListenerFluentImpl that = (IstioEgressListenerFluentImpl) o;
    if (!java.util.Objects.equals(bind, that.bind)) return false;

    if (!java.util.Objects.equals(captureMode, that.captureMode)) return false;

    if (!java.util.Objects.equals(hosts, that.hosts)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bind,  captureMode,  hosts,  port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bind != null) { sb.append("bind:"); sb.append(bind + ","); }
    if (captureMode != null) { sb.append("captureMode:"); sb.append(captureMode + ","); }
    if (hosts != null && !hosts.isEmpty()) { sb.append("hosts:"); sb.append(hosts + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  class PortNestedImpl<N> extends PortFluentImpl<IstioEgressListenerFluentImpl.PortNested<N>> implements IstioEgressListenerFluentImpl.PortNested<N>,Nested<N>{
    PortNestedImpl(Port item) {
      this.builder = new PortBuilder(this, item);
    }
    PortNestedImpl() {
      this.builder = new PortBuilder(this);
    }
    PortBuilder builder;
    public N and() {
      return (N) IstioEgressListenerFluentImpl.this.withPort(builder.build());
    }
    public N endPort() {
      return and();
    }
    
  }
  
}
